0.2.0
==================

* Adds any-var node `:*var` which matches multiple parts. The matcher is non-greedy.
* Adds `max_depth` param to `Routes` to limit how many parts to match when any-var is used
* Type annotations

0.1.0
==================

* Initial release
